@@ -1,4 +1,8 @@
-use std::borrow::Cow;
+#![no_std]
+
+extern crate alloc;
+
+use alloc::borrow::Cow;
 
 /// A trait for types that can be routed
 pub trait Request {
